@@ -1,24 +1,6 @@
-/*
-    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
-
-    This file is part of 0MQ.
-
-    0MQ is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
-    (at your option) any later version.
-
-    0MQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+/* SPDX-License-Identifier: MPL-2.0 */
 
 #include "../include/zmq.h"
-#include "../include/zmq_utils.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -97,7 +79,7 @@ static void *worker (void *ctx_)
 #endif
 }
 
-int main (int argc, char *argv [])
+int main (int argc, char *argv[])
 {
 #if defined ZMQ_HAVE_WINDOWS
     HANDLE local_thread;
@@ -118,8 +100,8 @@ int main (int argc, char *argv [])
         return 1;
     }
 
-    message_size = atoi (argv [1]);
-    roundtrip_count = atoi (argv [2]);
+    message_size = atoi (argv[1]);
+    roundtrip_count = atoi (argv[2]);
 
     ctx = zmq_init (1);
     if (!ctx) {
@@ -140,8 +122,7 @@ int main (int argc, char *argv [])
     }
 
 #if defined ZMQ_HAVE_WINDOWS
-    local_thread = (HANDLE) _beginthreadex (NULL, 0,
-        worker, ctx, 0 , NULL);
+    local_thread = (HANDLE) _beginthreadex (NULL, 0, worker, ctx, 0, NULL);
     if (local_thread == 0) {
         printf ("error in _beginthreadex\n");
         return -1;
@@ -220,12 +201,11 @@ int main (int argc, char *argv [])
         return -1;
     }
 
-    rc = zmq_term (ctx);
+    rc = zmq_ctx_term (ctx);
     if (rc != 0) {
-        printf ("error in zmq_term: %s\n", zmq_strerror (errno));
+        printf ("error in zmq_ctx_term: %s\n", zmq_strerror (errno));
         return -1;
     }
 
     return 0;
 }
-
